NextInvocation class

Next invocation data wraps the data from the invocation endpoint of the Lambda Runtime Interface.

Constructors

NextInvocation({required String requestId, String? deadlineMs, String? traceId, String? clientContext, String? cognitoIdentity, String? invokedFunctionArn, required Map<String, dynamic> response})
const

Properties

clientContext → String?
Client context is the context that is provided to the function.
final
cognitoIdentity → String?
Cognito identity is the identity that maybe is used for authorizing the request.
final
deadlineMs → String?
Deadline milliseconds is the setting for ultimate cancelation of the invocation.
final
hashCode → int
The hash code for this object.
no setterinherited
invokedFunctionArn → String?
Invoked function ARN is the identifier of the function.
final
requestId → String
Request Id is the identifier of the request.
final
response → Map<String, dynamic>
Raw response of invocation data that we received.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traceId → String?
Tracing id is the identifier for tracing like X-Ray.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromResponse(Response response) → Future<NextInvocation>
Digesting a HttpClientResponse into a NextInvocation.