AwsALBEvent class

Event send by an Application Load Balancer to the invocation to the Lambda.

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

AwsALBEvent({AwsALBEventContext? context, String? httpMethod, String? path, Map<String, dynamic>? headers, Map<String, dynamic>? queryStringParameters, String? body, bool? isBase64Encoded})
const
AwsALBEvent.fromJson(Map<String, dynamic> json)
factory

Properties

body → String?
Body of the request. This can be data that is send with the POST to the request.
final
context → AwsALBEventContext?
Request context in which this request is executed. For the ELB this is the ARN of the target group.
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, dynamic>?
HTTP headers that are send with the request to the load balancer.
final
httpMethod → String?
HTTP method that is used to trigger the invocation of the Lambda.
final
isBase64Encoded → bool?
Singals that the request is Base64 encoded.
final
path → String?
The URI that is accessed to trigger the invocation of the Lambda.
final
queryStringParameters → Map<String, dynamic>?
The query parameters for the request to the load balancer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited