AwsALBResponse class

Response for a request from an Application Load Balancer. It has to have a statusCode, headers and a body. They should reflect the informationen needed here.

Constructors

AwsALBResponse({String? body, Map<String, String>? headers, bool? isBase64Encoded, int? statusCode, String? statusDescription})
The Response that should be returned to the Application Load Balancer. It is constructed with some default values for the optional parameters.
AwsALBResponse.fromString(String body, {bool? isBase64Encoded, int? statusCode, String? statusDescription, Map<String, String>? headers})
factory

Properties

body ↔ String?
The body of the HTTP Response send from the API Gateway to the client.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>?
The HTTP headers that should be send with the response to the client.
getter/setter pair
isBase64Encoded ↔ bool?
Indicates if the body is Base64 encoded or not. By default is false.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode ↔ int?
HTTP status code of the response of the API Gateway to the client. The default status code is 200 OK.
getter/setter pair
statusDescription ↔ String?
Description of the send HTTP status code.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns the JSON representation of the response. This is called by the JSON encoder to produce the response.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited