AwsAlexaEventHeader class

Header are meta information about the event.

Annotations
  • @JsonSerializable.new()

Constructors

AwsAlexaEventHeader({String? namespace, String? payloadVersion, String? name})
const
AwsAlexaEventHeader.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
Name of the event
final
namespace → String?
Namespace of the event.
final
payloadVersion → String?
Version of the send payload.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited