AwsAppSyncEvent class

App Sync Event ...

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

AwsAppSyncEvent({String? version, String? operation, String? payload})
const
AwsAppSyncEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
operation → String?
final
payload → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited