AwsCloudwatchEvent class

Event that is send via SQS to trigger for an innovation of a Lambda.

Example

{
  "id": "cdc73f9d-aea9-11e3-9d5a-835b769c0d9c",
  "detail-type": "Scheduled Event",
  "source": "aws.events",
  "account": "{{{account-id}}}",
  "time": "1970-01-01T00:00:00Z",
  "region": "eu-west-1",
  "resources": [
    "arn:aws:events:eu-west-1:123456789012:rule/ExampleRule"
  ],
  "detail": {}
}
Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

AwsCloudwatchEvent({List<String>? resources, String? region, String? id, String? source, String? account, String? detailType, Map<String, dynamic>? detail, DateTime? time})
const
AwsCloudwatchEvent.fromJson(Map<String, dynamic> json)
factory

Properties

account → String?
Account ...
final
detail → Map<String, dynamic>?
Detail ...
final
detailType → String?
Data Type ...
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
Id ...
final
region → String?
Region ...
final
resources → List<String>?
Resources ...
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
Source ...
final
time → DateTime?
Time ...
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited