AwsDynamoDBUpdateEventRecord class

DynamoDB Update Event Record ...

Annotations
  • @JsonSerializable.new()

Constructors

AwsDynamoDBUpdateEventRecord({String? eventId, String? eventName, String? eventSource, String? eventVersion, String? awsRegion, String? eventSourceARN})
const
AwsDynamoDBUpdateEventRecord.fromJson(Map<String, dynamic> json)
factory

Properties

awsRegion → String?
AWS Region ...
final
eventId → String?
Event Id ...
final
eventName → String?
Event Name ...
final
eventSource → String?
Event Source ...
final
eventSourceARN → String?
Event Source ARN ...
final
eventVersion → String?
Event Version ...
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited