AWSS3EventObject class

Annotations
  • @JsonSerializable.new()

Constructors

AWSS3EventObject({String? key, int? size, String? eTag, String? sequencer})
AWSS3EventObject.fromJson(Map<String, dynamic> json)
factory

Properties

eTag ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequencer ↔ String?
getter/setter pair
size ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited