AwsS3Data class

Annotations
  • @JsonSerializable.new()

Constructors

AwsS3Data({String? s3SchemaVersion, String? configurationId, AwsS3Bucket? bucket, AWSS3EventObject? object})
AwsS3Data.fromJson(Map<String, dynamic> json)
factory

Properties

bucket ↔ AwsS3Bucket?
getter/setter pair
configurationId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
object ↔ AWSS3EventObject?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3SchemaVersion ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited