AwsS3EventRecord class

Notifcation Event for Lambda in S3.

Annotations
  • @JsonSerializable.new()

Constructors

AwsS3EventRecord({String? eventName, String? eventSource, String? awsRegion, DateTime? eventTime, String? eventVersion, AwsS3UserIdentity? userIdentity, Map<String, String>? requestParameters, Map<String, String>? responseElements, AwsS3Data? s3})
const
AwsS3EventRecord.fromJson(Map<String, dynamic> json)
factory

Properties

awsRegion → String?
final
eventName → String?
final
eventSource → String?
final
eventTime → DateTime?
final
eventVersion → String?
final
hashCode → int
The hash code for this object.
no setterinherited
requestParameters → Map<String, String>?
final
responseElements → Map<String, String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3 → AwsS3Data?
final
userIdentity → AwsS3UserIdentity?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited