RuntimeException class

An exception thrown when there is an error in the runtime.

Implemented types

Constructors

RuntimeException(String cause)
const

Properties

cause → String
Explains the reason why there is an exception thrown in the runtime.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited